==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-pane-pinned-event-args.js <==
import { PanePinnedEventArgs as PanePinnedEventArgs_internal } from "./PanePinnedEventArgs";
var IgrPanePinnedEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPanePinnedEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrPanePinnedEventArgs.prototype.createImplementation = function () {
        return new PanePinnedEventArgs_internal();
    };
    Object.defineProperty(IgrPanePinnedEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPanePinnedEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPanePinnedEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrPanePinnedEventArgs.prototype, "detail", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            if (!this.i.a.externalObject) {
                var e = new IgrPanePinnedEventArgs();
                e._implementation = this.i.a;
                this.i.a.externalObject = e;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPanePinnedEventArgs;
}());
export { IgrPanePinnedEventArgs };

==> igniteui-react-18.6.0.tgz: package/esm5/lib/igr-pane-pinned-event-args.js <==
import { IgrPanePinnedEventArgsDetail } from "./igr-pane-pinned-event-args-detail";
import { PanePinnedEventArgs as PanePinnedEventArgs_internal } from "./PanePinnedEventArgs";
var IgrPanePinnedEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPanePinnedEventArgs() {
        this.mounted = false;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrPanePinnedEventArgs.prototype.createImplementation = function () {
        return new PanePinnedEventArgs_internal();
    };
    Object.defineProperty(IgrPanePinnedEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPanePinnedEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPanePinnedEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrPanePinnedEventArgs.prototype, "detail", {
        get: function () {
            var r = this.i.b;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrPanePinnedEventArgsDetail();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.b = null : this.i.b = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPanePinnedEventArgs;
}());
export { IgrPanePinnedEventArgs };
